package com.hzya.frame.nifi.config;

import okhttp3.OkHttpClient;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import java.security.SecureRandom;
import java.security.cert.X509Certificate;
import java.util.concurrent.TimeUnit;

/**
 * OkHttpClient配置类
 * @Author：liuyang
 * @Package：com.hzya.frame.nifi.config
 * @Project：fw-nifi
 * @name：HttpClientConfig
 * @Date：2025/5/14 11:45
 * @Filename：HttpClientConfig
 */
@Configuration
public class HttpClientConfig {

    @Bean
    public OkHttpClient okHttpClient() throws Exception {
        return new OkHttpClient.Builder().sslSocketFactory(createTrustAllSslSocketFactory(), createTrustAllTrustManager())
                .hostnameVerifier((hostname, session) -> true)
                .connectTimeout(60, TimeUnit.SECONDS) // 连接超时时间
                .readTimeout(60, TimeUnit.SECONDS)   // 读取超时时间
                .writeTimeout(60, TimeUnit.SECONDS)  // 写入超时时间
                .build();
    }

    private SSLSocketFactory createTrustAllSslSocketFactory() throws Exception {
        SSLContext sslContext = SSLContext.getInstance("SSL");
        sslContext.init(null, new TrustManager[]{createTrustAllTrustManager()}, new SecureRandom());
        return sslContext.getSocketFactory();
    }

    private X509TrustManager createTrustAllTrustManager() {
        return new X509TrustManager() {
            @Override
            public void checkClientTrusted(X509Certificate[] chain, String authType) {
            }

            @Override
            public void checkServerTrusted(X509Certificate[] chain, String authType) {
            }

            @Override
            public X509Certificate[] getAcceptedIssuers() {
                return new X509Certificate[0];
            }
        };
    }
}
